@@ -32,7 +32,7 @@ class Get_Top_Keyword:
             get_app_keyword_data.keyword_hot_start = self.keyword_hot_start
             res = get_app_keyword_data.get_keywordDetail()
             if res['msg'] == '成功' and len(res['data']) > 0:
-                df_keyword = Qimai_Outside_Tool(*[res['data']]).json_to_df()
+                df_keyword = Qimai_Outside_Tool(res['data']).json_to_df()
                 df_keyword.columns = ['关键词ID', '关键词', '排名', '变动前排名', '排名变动值', '指数', '结果数', '未知1', '未知2']
 
                 t1_all_num = df_keyword[(df_keyword['排名'] <= 1) & (df_keyword['指数'] >= self.keyword_hot_start) & (df_keyword['指数'] <= self.keyword_hot_end) & (df_keyword['排名变动值'] != 'lost')].shape[0]
